==> buenos-1.0.0.tar.gz: buenos/drivers/gcd.h <==
/*
 * Generic character device
 *
 * Copyright (C) 2003 Juha Aatrokoski, Timo Lilja,
 *   Leena Salmela, Teemu Takanen, Aleksi Virtanen.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: gcd.h,v 1.1 2003/03/04 15:30:31 lsalmela Exp $
 *
 */

#ifndef DRIVERS_GCD_H
#define DRIVERS_GCD_H

#include "drivers/device.h"

/* Generic character device descriptor. */
typedef struct gcd_struct {
    /* Pointer to the device */
    device_t *device;

    /* Pointer to a function which writes len bytes from buf to the
       device. This function returns the number of bytes successfully
       written. Note the call can block. */
    int (*write)(struct gcd_struct *gcd, void *buf, int len);

    /* Pointer to a function which reads at most len bytes from the
       device to buf. The function returns the number of bytes read.
       Note the call can block. */
    int  (*read)(struct gcd_struct *gcd, void *buf, int len);
} gcd_t;

#endif /* DRIVERS_GCD_H */

==> buenos-1.1.3.tar.gz: buenos/drivers/gcd.h <==
/*
 * Generic character device
 *
 * Copyright (C) 2003 Juha Aatrokoski, Timo Lilja,
 *   Leena Salmela, Teemu Takanen, Aleksi Virtanen.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: gcd.h,v 1.2 2004/01/13 11:10:50 ttakanen Exp $
 *
 */

#ifndef DRIVERS_GCD_H
#define DRIVERS_GCD_H

#include "drivers/device.h"

/* Generic character device descriptor. */
typedef struct gcd_struct {
    /* Pointer to the device */
    device_t *device;

    /* Pointer to a function which writes len bytes from buf to the
       device. This function returns the number of bytes successfully
       written. Note the call can block. */
    int (*write)(struct gcd_struct *gcd, const void *buf, int len);

    /* Pointer to a function which reads at most len bytes from the
       device to buf. The function returns the number of bytes read.
       Note the call can block. */
    int  (*read)(struct gcd_struct *gcd, void *buf, int len);
} gcd_t;

#endif /* DRIVERS_GCD_H */
